aboutsummaryrefslogtreecommitdiffstats
path: root/packages/contracts/src
diff options
context:
space:
mode:
authorGreg Hysen <greg.hysen@gmail.com>2018-06-20 08:27:09 +0800
committerGreg Hysen <greg.hysen@gmail.com>2018-06-21 04:54:39 +0800
commit2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81 (patch)
treed9a0f97751ee8a92b4ecc80426b156e52fd50188 /packages/contracts/src
parent94e260cec668875aa957cbb8c7f241eb9e4f4961 (diff)
downloaddexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar.gz
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar.bz2
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar.lz
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar.xz
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.tar.zst
dexon-sol-tools-2c7358d64ffb0e9fcbc462bbe3cd89edd67cec81.zip
Minor style tweaks
Diffstat (limited to 'packages/contracts/src')
-rw-r--r--packages/contracts/src/contracts/current/protocol/Exchange/mixins/MSignatureValidator.sol2
-rw-r--r--packages/contracts/src/contracts/current/test/TestValidator/TestValidator.sol2
-rw-r--r--packages/contracts/src/contracts/current/test/TestWallet/TestWallet.sol12
3 files changed, 8 insertions, 8 deletions
diff --git a/packages/contracts/src/contracts/current/protocol/Exchange/mixins/MSignatureValidator.sol b/packages/contracts/src/contracts/current/protocol/Exchange/mixins/MSignatureValidator.sol
index 0cab95193..9c6fbe22b 100644
--- a/packages/contracts/src/contracts/current/protocol/Exchange/mixins/MSignatureValidator.sol
+++ b/packages/contracts/src/contracts/current/protocol/Exchange/mixins/MSignatureValidator.sol
@@ -34,6 +34,6 @@ contract MSignatureValidator is
Validator, // 0x06
PreSigned, // 0x07
Trezor, // 0x08
- NSignatureTypes // 0x09, always leave at end.
+ NSignatureTypes // 0x09, number of signature types. Always leave at end.
}
}
diff --git a/packages/contracts/src/contracts/current/test/TestValidator/TestValidator.sol b/packages/contracts/src/contracts/current/test/TestValidator/TestValidator.sol
index ba661f89d..c0daf8f38 100644
--- a/packages/contracts/src/contracts/current/test/TestValidator/TestValidator.sol
+++ b/packages/contracts/src/contracts/current/test/TestValidator/TestValidator.sol
@@ -33,7 +33,7 @@ contract TestValidator is
validSigner = _validSigner;
}
- /// @dev Verifies that a signature is valid.
+ /// @dev Verifies that a signature is valid.
/// @param hash Message hash that is signed.
/// @param signer Address that should have signed the given hash.
/// @param signature Proof of signing.
diff --git a/packages/contracts/src/contracts/current/test/TestWallet/TestWallet.sol b/packages/contracts/src/contracts/current/test/TestWallet/TestWallet.sol
index 5baba1d98..51556971d 100644
--- a/packages/contracts/src/contracts/current/test/TestWallet/TestWallet.sol
+++ b/packages/contracts/src/contracts/current/test/TestWallet/TestWallet.sol
@@ -40,24 +40,24 @@ contract TestWallet is
/// @dev Validates an EIP712 signature.
/// The signer must match the signer of this wallet.
/// @param hash Message hash that is signed.
/// @param eip721Signature Proof of signing.
/// @return Validity of order signature.
function isValidSignature(
bytes32 hash,
- bytes eip721Signature
+ bytes eip712Signature
)
external
view
returns (bool isValid)
{
require(
- eip721Signature.length == 65,
+ eip712Signature.length == 65,
LENGTH_65_REQUIRED
);
- uint8 v = uint8(eip721Signature[0]);
- bytes32 r = readBytes32(eip721Signature, 1);
- bytes32 s = readBytes32(eip721Signature, 33);
+ uint8 v = uint8(eip712Signature[0]);
+ bytes32 r = readBytes32(eip712Signature, 1);
+ bytes32 s = readBytes32(eip712Signature, 33);
address recoveredAddress = ecrecover(hash, v, r, s);
isValid = walletOwner == recoveredAddress;
return isValid;
@@ -40,24 +40,24 @@ contract TestWallet is
/// The signer must match the signer of this wallet.
/// @param hash Message hash that is signed.
- /// @param eip721Signature Proof of signing.
+ /// @param eip712Signature Proof of signing.
/// @return Validity of order signature.
function isValidSignature(